@@ -233,6 +233,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -284,18 +285,18 @@ instance B.Types.TypedObject GridLayoutChild where
 
 instance B.Types.GObject GridLayoutChild
 
--- | Type class for types which can be safely cast to `GridLayoutChild`, for instance with `toGridLayoutChild`.
+-- | Type class for types which can be safely cast to t'GridLayoutChild', for instance with `toGridLayoutChild`.
 class (SP.GObject o, O.IsDescendantOf GridLayoutChild o) => IsGridLayoutChild o
 instance (SP.GObject o, O.IsDescendantOf GridLayoutChild o) => IsGridLayoutChild o
 
 instance O.HasParentTypes GridLayoutChild
 type instance O.ParentTypes GridLayoutChild = '[Gtk.LayoutChild.LayoutChild, GObject.Object.Object]
 
--- | Cast to `GridLayoutChild`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'GridLayoutChild', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toGridLayoutChild :: (MIO.MonadIO m, IsGridLayoutChild o) => o -> m GridLayoutChild
 toGridLayoutChild = MIO.liftIO . B.ManagedPtr.unsafeCastTo GridLayoutChild
 
--- | Convert 'GridLayoutChild' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'GridLayoutChild' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe GridLayoutChild) where
     gvalueGType_ = c_gtk_grid_layout_child_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr GridLayoutChild)
@@ -390,7 +391,7 @@ setGridLayoutChildColumn :: (MonadIO m, IsGridLayoutChild o) => o -> Int32 -> m
 setGridLayoutChildColumn obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyInt32 obj "column" val
 
--- | Construct a `GValueConstruct` with valid value for the “@column@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@column@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructGridLayoutChildColumn :: (IsGridLayoutChild o, MIO.MonadIO m) => Int32 -> m (GValueConstruct o)
 constructGridLayoutChildColumn val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyInt32 "column" val
@@ -414,7 +415,7 @@ instance AttrInfo GridLayoutChildColumnPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.column"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#g:attr:column"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#g:attr:column"
         })
 #endif
 
@@ -442,7 +443,7 @@ setGridLayoutChildColumnSpan :: (MonadIO m, IsGridLayoutChild o) => o -> Int32 -
 setGridLayoutChildColumnSpan obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyInt32 obj "column-span" val
 
--- | Construct a `GValueConstruct` with valid value for the “@column-span@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@column-span@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructGridLayoutChildColumnSpan :: (IsGridLayoutChild o, MIO.MonadIO m) => Int32 -> m (GValueConstruct o)
 constructGridLayoutChildColumnSpan val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyInt32 "column-span" val
@@ -466,7 +467,7 @@ instance AttrInfo GridLayoutChildColumnSpanPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.columnSpan"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#g:attr:columnSpan"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#g:attr:columnSpan"
         })
 #endif
 
@@ -494,7 +495,7 @@ setGridLayoutChildRow :: (MonadIO m, IsGridLayoutChild o) => o -> Int32 -> m ()
 setGridLayoutChildRow obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyInt32 obj "row" val
 
--- | Construct a `GValueConstruct` with valid value for the “@row@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@row@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructGridLayoutChildRow :: (IsGridLayoutChild o, MIO.MonadIO m) => Int32 -> m (GValueConstruct o)
 constructGridLayoutChildRow val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyInt32 "row" val
@@ -518,7 +519,7 @@ instance AttrInfo GridLayoutChildRowPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.row"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#g:attr:row"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#g:attr:row"
         })
 #endif
 
@@ -546,7 +547,7 @@ setGridLayoutChildRowSpan :: (MonadIO m, IsGridLayoutChild o) => o -> Int32 -> m
 setGridLayoutChildRowSpan obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyInt32 obj "row-span" val
 
--- | Construct a `GValueConstruct` with valid value for the “@row-span@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@row-span@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructGridLayoutChildRowSpan :: (IsGridLayoutChild o, MIO.MonadIO m) => Int32 -> m (GValueConstruct o)
 constructGridLayoutChildRowSpan val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyInt32 "row-span" val
@@ -570,7 +571,7 @@ instance AttrInfo GridLayoutChildRowSpanPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.rowSpan"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#g:attr:rowSpan"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#g:attr:rowSpan"
         })
 #endif
 
@@ -652,7 +653,7 @@ instance (signature ~ (m Int32), MonadIO m, IsGridLayoutChild a) => O.Overloaded
 instance O.OverloadedMethodInfo GridLayoutChildGetColumnMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.gridLayoutChildGetColumn",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildGetColumn"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildGetColumn"
         })
 
 
@@ -709,7 +710,7 @@ instance (signature ~ (m Int32), MonadIO m, IsGridLayoutChild a) => O.Overloaded
 instance O.OverloadedMethodInfo GridLayoutChildGetColumnSpanMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.gridLayoutChildGetColumnSpan",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildGetColumnSpan"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildGetColumnSpan"
         })
 
 
@@ -766,7 +767,7 @@ instance (signature ~ (m Int32), MonadIO m, IsGridLayoutChild a) => O.Overloaded
 instance O.OverloadedMethodInfo GridLayoutChildGetRowMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.gridLayoutChildGetRow",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildGetRow"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildGetRow"
         })
 
 
@@ -823,7 +824,7 @@ instance (signature ~ (m Int32), MonadIO m, IsGridLayoutChild a) => O.Overloaded
 instance O.OverloadedMethodInfo GridLayoutChildGetRowSpanMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.gridLayoutChildGetRowSpan",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildGetRowSpan"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildGetRowSpan"
         })
 
 
@@ -899,7 +900,7 @@ instance (signature ~ (Int32 -> m ()), MonadIO m, IsGridLayoutChild a) => O.Over
 instance O.OverloadedMethodInfo GridLayoutChildSetColumnMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.gridLayoutChildSetColumn",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildSetColumn"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildSetColumn"
         })
 
 
@@ -973,7 +974,7 @@ instance (signature ~ (Int32 -> m ()), MonadIO m, IsGridLayoutChild a) => O.Over
 instance O.OverloadedMethodInfo GridLayoutChildSetColumnSpanMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.gridLayoutChildSetColumnSpan",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildSetColumnSpan"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildSetColumnSpan"
         })
 
 
@@ -1047,7 +1048,7 @@ instance (signature ~ (Int32 -> m ()), MonadIO m, IsGridLayoutChild a) => O.Over
 instance O.OverloadedMethodInfo GridLayoutChildSetRowMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.gridLayoutChildSetRow",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildSetRow"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildSetRow"
         })
 
 
@@ -1121,7 +1122,7 @@ instance (signature ~ (Int32 -> m ()), MonadIO m, IsGridLayoutChild a) => O.Over
 instance O.OverloadedMethodInfo GridLayoutChildSetRowSpanMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.GridLayoutChild.gridLayoutChildSetRowSpan",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildSetRowSpan"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-GridLayoutChild.html#v:gridLayoutChildSetRowSpan"
         })
 
 
