@@ -19,6 +19,8 @@
 -- 
 -- 2. The bound stage where the listitem references an item from the list.
 --    The [ListItem:item]("GI.Gtk.Objects.ListItem#g:attr:item") property is not @NULL@.
+-- 
+-- 
 
 #if (MIN_VERSION_haskell_gi_overloading(1,0,0) && !defined(__HADDOCK_VERSION__))
 #define ENABLE_OVERLOADING
@@ -373,6 +375,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -424,18 +427,18 @@ instance B.Types.TypedObject ListItem where
 
 instance B.Types.GObject ListItem
 
--- | Type class for types which can be safely cast to `ListItem`, for instance with `toListItem`.
+-- | Type class for types which can be safely cast to t'ListItem', for instance with `toListItem`.
 class (SP.GObject o, O.IsDescendantOf ListItem o) => IsListItem o
 instance (SP.GObject o, O.IsDescendantOf ListItem o) => IsListItem o
 
 instance O.HasParentTypes ListItem
 type instance O.ParentTypes ListItem = '[GObject.Object.Object]
 
--- | Cast to `ListItem`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'ListItem', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toListItem :: (MIO.MonadIO m, IsListItem o) => o -> m ListItem
 toListItem = MIO.liftIO . B.ManagedPtr.unsafeCastTo ListItem
 
--- | Convert 'ListItem' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'ListItem' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe ListItem) where
     gvalueGType_ = c_gtk_list_item_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr ListItem)
@@ -535,7 +538,7 @@ setListItemAccessibleDescription :: (MonadIO m, IsListItem o) => o -> T.Text ->
 setListItemAccessibleDescription obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyString obj "accessible-description" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@accessible-description@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@accessible-description@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructListItemAccessibleDescription :: (IsListItem o, MIO.MonadIO m) => T.Text -> m (GValueConstruct o)
 constructListItemAccessibleDescription val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyString "accessible-description" (P.Just val)
@@ -559,7 +562,7 @@ instance AttrInfo ListItemAccessibleDescriptionPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.accessibleDescription"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#g:attr:accessibleDescription"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#g:attr:accessibleDescription"
         })
 #endif
 
@@ -587,7 +590,7 @@ setListItemAccessibleLabel :: (MonadIO m, IsListItem o) => o -> T.Text -> m ()
 setListItemAccessibleLabel obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyString obj "accessible-label" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@accessible-label@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@accessible-label@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructListItemAccessibleLabel :: (IsListItem o, MIO.MonadIO m) => T.Text -> m (GValueConstruct o)
 constructListItemAccessibleLabel val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyString "accessible-label" (P.Just val)
@@ -611,7 +614,7 @@ instance AttrInfo ListItemAccessibleLabelPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.accessibleLabel"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#g:attr:accessibleLabel"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#g:attr:accessibleLabel"
         })
 #endif
 
@@ -639,7 +642,7 @@ setListItemActivatable :: (MonadIO m, IsListItem o) => o -> Bool -> m ()
 setListItemActivatable obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "activatable" val
 
--- | Construct a `GValueConstruct` with valid value for the “@activatable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@activatable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructListItemActivatable :: (IsListItem o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructListItemActivatable val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "activatable" val
@@ -663,7 +666,7 @@ instance AttrInfo ListItemActivatablePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.activatable"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#g:attr:activatable"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#g:attr:activatable"
         })
 #endif
 
@@ -691,7 +694,7 @@ setListItemChild :: (MonadIO m, IsListItem o, Gtk.Widget.IsWidget a) => o -> a -
 setListItemChild obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyObject obj "child" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructListItemChild :: (IsListItem o, MIO.MonadIO m, Gtk.Widget.IsWidget a) => a -> m (GValueConstruct o)
 constructListItemChild val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "child" (P.Just val)
@@ -724,7 +727,7 @@ instance AttrInfo ListItemChildPropertyInfo where
     attrClear = clearListItemChild
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.child"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#g:attr:child"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#g:attr:child"
         })
 #endif
 
@@ -752,7 +755,7 @@ setListItemFocusable :: (MonadIO m, IsListItem o) => o -> Bool -> m ()
 setListItemFocusable obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "focusable" val
 
--- | Construct a `GValueConstruct` with valid value for the “@focusable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@focusable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructListItemFocusable :: (IsListItem o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructListItemFocusable val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "focusable" val
@@ -776,7 +779,7 @@ instance AttrInfo ListItemFocusablePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.focusable"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#g:attr:focusable"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#g:attr:focusable"
         })
 #endif
 
@@ -812,7 +815,7 @@ instance AttrInfo ListItemItemPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.item"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#g:attr:item"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#g:attr:item"
         })
 #endif
 
@@ -848,7 +851,7 @@ instance AttrInfo ListItemPositionPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.position"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#g:attr:position"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#g:attr:position"
         })
 #endif
 
@@ -876,7 +879,7 @@ setListItemSelectable :: (MonadIO m, IsListItem o) => o -> Bool -> m ()
 setListItemSelectable obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "selectable" val
 
--- | Construct a `GValueConstruct` with valid value for the “@selectable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@selectable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructListItemSelectable :: (IsListItem o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructListItemSelectable val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "selectable" val
@@ -900,7 +903,7 @@ instance AttrInfo ListItemSelectablePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.selectable"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#g:attr:selectable"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#g:attr:selectable"
         })
 #endif
 
@@ -936,7 +939,7 @@ instance AttrInfo ListItemSelectedPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.selected"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#g:attr:selected"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#g:attr:selected"
         })
 #endif
 
@@ -1035,7 +1038,7 @@ instance (signature ~ (m T.Text), MonadIO m, IsListItem a) => O.OverloadedMethod
 instance O.OverloadedMethodInfo ListItemGetAccessibleDescriptionMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemGetAccessibleDescription",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetAccessibleDescription"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetAccessibleDescription"
         })
 
 
@@ -1094,7 +1097,7 @@ instance (signature ~ (m T.Text), MonadIO m, IsListItem a) => O.OverloadedMethod
 instance O.OverloadedMethodInfo ListItemGetAccessibleLabelMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemGetAccessibleLabel",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetAccessibleLabel"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetAccessibleLabel"
         })
 
 
@@ -1151,7 +1154,7 @@ instance (signature ~ (m Bool), MonadIO m, IsListItem a) => O.OverloadedMethod L
 instance O.OverloadedMethodInfo ListItemGetActivatableMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemGetActivatable",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetActivatable"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetActivatable"
         })
 
 
@@ -1210,7 +1213,7 @@ instance (signature ~ (m (Maybe Gtk.Widget.Widget)), MonadIO m, IsListItem a) =>
 instance O.OverloadedMethodInfo ListItemGetChildMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemGetChild",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetChild"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetChild"
         })
 
 
@@ -1269,7 +1272,7 @@ instance (signature ~ (m Bool), MonadIO m, IsListItem a) => O.OverloadedMethod L
 instance O.OverloadedMethodInfo ListItemGetFocusableMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemGetFocusable",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetFocusable"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetFocusable"
         })
 
 
@@ -1329,7 +1332,7 @@ instance (signature ~ (m (Maybe GObject.Object.Object)), MonadIO m, IsListItem a
 instance O.OverloadedMethodInfo ListItemGetItemMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemGetItem",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetItem"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetItem"
         })
 
 
@@ -1386,7 +1389,7 @@ instance (signature ~ (m Word32), MonadIO m, IsListItem a) => O.OverloadedMethod
 instance O.OverloadedMethodInfo ListItemGetPositionMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemGetPosition",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetPosition"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetPosition"
         })
 
 
@@ -1445,7 +1448,7 @@ instance (signature ~ (m Bool), MonadIO m, IsListItem a) => O.OverloadedMethod L
 instance O.OverloadedMethodInfo ListItemGetSelectableMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemGetSelectable",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetSelectable"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetSelectable"
         })
 
 
@@ -1504,7 +1507,7 @@ instance (signature ~ (m Bool), MonadIO m, IsListItem a) => O.OverloadedMethod L
 instance O.OverloadedMethodInfo ListItemGetSelectedMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemGetSelected",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetSelected"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemGetSelected"
         })
 
 
@@ -1582,7 +1585,7 @@ instance (signature ~ (T.Text -> m ()), MonadIO m, IsListItem a) => O.Overloaded
 instance O.OverloadedMethodInfo ListItemSetAccessibleDescriptionMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemSetAccessibleDescription",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetAccessibleDescription"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetAccessibleDescription"
         })
 
 
@@ -1660,7 +1663,7 @@ instance (signature ~ (T.Text -> m ()), MonadIO m, IsListItem a) => O.Overloaded
 instance O.OverloadedMethodInfo ListItemSetAccessibleLabelMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemSetAccessibleLabel",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetAccessibleLabel"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetAccessibleLabel"
         })
 
 
@@ -1743,7 +1746,7 @@ instance (signature ~ (Bool -> m ()), MonadIO m, IsListItem a) => O.OverloadedMe
 instance O.OverloadedMethodInfo ListItemSetActivatableMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemSetActivatable",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetActivatable"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetActivatable"
         })
 
 
@@ -1827,7 +1830,7 @@ instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsListItem a, Gtk.Widget.I
 instance O.OverloadedMethodInfo ListItemSetChildMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemSetChild",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetChild"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetChild"
         })
 
 
@@ -1912,7 +1915,7 @@ instance (signature ~ (Bool -> m ()), MonadIO m, IsListItem a) => O.OverloadedMe
 instance O.OverloadedMethodInfo ListItemSetFocusableMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemSetFocusable",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetFocusable"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetFocusable"
         })
 
 
@@ -1998,7 +2001,7 @@ instance (signature ~ (Bool -> m ()), MonadIO m, IsListItem a) => O.OverloadedMe
 instance O.OverloadedMethodInfo ListItemSetSelectableMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListItem.listItemSetSelectable",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetSelectable"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListItem.html#v:listItemSetSelectable"
         })
 
 
