@@ -18,18 +18,18 @@
 -- little more work:
 -- 
 -- * Set the [Widget:hasTooltip]("GI.Gtk.Objects.Widget#g:attr:hasTooltip") property to 'P.True'.
--- This will make GTK monitor the widget for motion and related events
--- which are needed to determine when and where to show a tooltip.
+--   This will make GTK monitor the widget for motion and related events
+--   which are needed to determine when and where to show a tooltip.
 -- * Connect to the [Widget::queryTooltip]("GI.Gtk.Objects.Widget#g:signal:queryTooltip") signal.
--- This signal will be emitted when a tooltip is supposed to be shown.
--- One of the arguments passed to the signal handler is a @GtkTooltip@
--- object. This is the object that we are about to display as a tooltip,
--- and can be manipulated in your callback using functions like
--- 'GI.Gtk.Objects.Tooltip.tooltipSetIcon'. There are functions for setting
--- the tooltip’s markup, setting an image from a named icon, or even
--- putting in a custom widget.
+--   This signal will be emitted when a tooltip is supposed to be shown.
+--   One of the arguments passed to the signal handler is a @GtkTooltip@
+--   object. This is the object that we are about to display as a tooltip,
+--   and can be manipulated in your callback using functions like
+--   'GI.Gtk.Objects.Tooltip.tooltipSetIcon'. There are functions for setting
+--   the tooltip’s markup, setting an image from a named icon, or even
+--   putting in a custom widget.
 -- * Return 'P.True' from your [queryTooltip](#g:signal:queryTooltip) handler. This causes the tooltip
--- to be show. If you return 'P.False', it will not be shown.
+--   to be show. If you return 'P.False', it will not be shown.
 -- 
 
 #if (MIN_VERSION_haskell_gi_overloading(1,0,0) && !defined(__HADDOCK_VERSION__))
@@ -189,6 +189,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -242,18 +243,18 @@ instance B.Types.TypedObject Tooltip where
 
 instance B.Types.GObject Tooltip
 
--- | Type class for types which can be safely cast to `Tooltip`, for instance with `toTooltip`.
+-- | Type class for types which can be safely cast to t'Tooltip', for instance with `toTooltip`.
 class (SP.GObject o, O.IsDescendantOf Tooltip o) => IsTooltip o
 instance (SP.GObject o, O.IsDescendantOf Tooltip o) => IsTooltip o
 
 instance O.HasParentTypes Tooltip
 type instance O.ParentTypes Tooltip = '[GObject.Object.Object]
 
--- | Cast to `Tooltip`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'Tooltip', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toTooltip :: (MIO.MonadIO m, IsTooltip o) => o -> m Tooltip
 toTooltip = MIO.liftIO . B.ManagedPtr.unsafeCastTo Tooltip
 
--- | Convert 'Tooltip' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'Tooltip' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe Tooltip) where
     gvalueGType_ = c_gtk_tooltip_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr Tooltip)
@@ -416,7 +417,7 @@ instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsTooltip a, Gtk.Widget.Is
 instance O.OverloadedMethodInfo TooltipSetCustomMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Tooltip.tooltipSetCustom",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetCustom"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetCustom"
         })
 
 
@@ -496,7 +497,7 @@ instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsTooltip a, Gdk.Paintable
 instance O.OverloadedMethodInfo TooltipSetIconMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Tooltip.tooltipSetIcon",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetIcon"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetIcon"
         })
 
 
@@ -578,7 +579,7 @@ instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsTooltip a, Gio.Icon.IsIc
 instance O.OverloadedMethodInfo TooltipSetIconFromGiconMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Tooltip.tooltipSetIconFromGicon",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetIconFromGicon"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetIconFromGicon"
         })
 
 
@@ -658,7 +659,7 @@ instance (signature ~ (Maybe (T.Text) -> m ()), MonadIO m, IsTooltip a) => O.Ove
 instance O.OverloadedMethodInfo TooltipSetIconFromIconNameMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Tooltip.tooltipSetIconFromIconName",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetIconFromIconName"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetIconFromIconName"
         })
 
 
@@ -741,7 +742,7 @@ instance (signature ~ (Maybe (T.Text) -> m ()), MonadIO m, IsTooltip a) => O.Ove
 instance O.OverloadedMethodInfo TooltipSetMarkupMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Tooltip.tooltipSetMarkup",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetMarkup"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetMarkup"
         })
 
 
@@ -822,7 +823,7 @@ instance (signature ~ (Maybe (T.Text) -> m ()), MonadIO m, IsTooltip a) => O.Ove
 instance O.OverloadedMethodInfo TooltipSetTextMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Tooltip.tooltipSetText",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetText"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetText"
         })
 
 
@@ -904,7 +905,7 @@ instance (signature ~ (Gdk.Rectangle.Rectangle -> m ()), MonadIO m, IsTooltip a)
 instance O.OverloadedMethodInfo TooltipSetTipAreaMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Tooltip.tooltipSetTipArea",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetTipArea"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Tooltip.html#v:tooltipSetTipArea"
         })
 
 
